<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>PianoPalette</name>
    <message>
        <location filename="../pianopalette.cpp" line="143"/>
        <location filename="../pianopalette.cpp" line="215"/>
        <location filename="../pianopalette.cpp" line="226"/>
        <location filename="../pianopalette.cpp" line="297"/>
        <location filename="../pianopalette.cpp" line="354"/>
        <location filename="../pianopalette.cpp" line="365"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="144"/>
        <location filename="../pianopalette.cpp" line="216"/>
        <location filename="../pianopalette.cpp" line="227"/>
        <location filename="../pianopalette.cpp" line="298"/>
        <location filename="../pianopalette.cpp" line="355"/>
        <location filename="../pianopalette.cpp" line="366"/>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="154"/>
        <location filename="../pianopalette.cpp" line="308"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="155"/>
        <location filename="../pianopalette.cpp" line="309"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="156"/>
        <location filename="../pianopalette.cpp" line="310"/>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="157"/>
        <location filename="../pianopalette.cpp" line="311"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="158"/>
        <location filename="../pianopalette.cpp" line="312"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="159"/>
        <location filename="../pianopalette.cpp" line="313"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="160"/>
        <location filename="../pianopalette.cpp" line="314"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="161"/>
        <location filename="../pianopalette.cpp" line="315"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="162"/>
        <location filename="../pianopalette.cpp" line="316"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="163"/>
        <location filename="../pianopalette.cpp" line="317"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="164"/>
        <location filename="../pianopalette.cpp" line="318"/>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="165"/>
        <location filename="../pianopalette.cpp" line="319"/>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="166"/>
        <location filename="../pianopalette.cpp" line="320"/>
        <source>13</source>
        <translation>13</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="167"/>
        <location filename="../pianopalette.cpp" line="321"/>
        <source>14</source>
        <translation>14</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="168"/>
        <location filename="../pianopalette.cpp" line="322"/>
        <source>15</source>
        <translation>15</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="169"/>
        <location filename="../pianopalette.cpp" line="323"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="194"/>
        <location filename="../pianopalette.cpp" line="333"/>
        <source>C</source>
        <translation>do</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="195"/>
        <location filename="../pianopalette.cpp" line="334"/>
        <source>C#</source>
        <translation>do#</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="196"/>
        <location filename="../pianopalette.cpp" line="335"/>
        <source>D</source>
        <translation>re</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="197"/>
        <location filename="../pianopalette.cpp" line="336"/>
        <source>D#</source>
        <translation>re#</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="198"/>
        <location filename="../pianopalette.cpp" line="337"/>
        <source>E</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="199"/>
        <location filename="../pianopalette.cpp" line="338"/>
        <source>F</source>
        <translation>fa</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="200"/>
        <location filename="../pianopalette.cpp" line="339"/>
        <source>F#</source>
        <translation>fa#</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="201"/>
        <location filename="../pianopalette.cpp" line="340"/>
        <source>G</source>
        <translation>sol</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="202"/>
        <location filename="../pianopalette.cpp" line="341"/>
        <source>G#</source>
        <translation>sol#</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="203"/>
        <location filename="../pianopalette.cpp" line="342"/>
        <source>A</source>
        <translation>la</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="204"/>
        <location filename="../pianopalette.cpp" line="343"/>
        <source>A#</source>
        <translation>la#</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="205"/>
        <location filename="../pianopalette.cpp" line="344"/>
        <source>B</source>
        <translation>si</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="228"/>
        <location filename="../pianopalette.cpp" line="367"/>
        <source>N*</source>
        <translation>N*</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="229"/>
        <location filename="../pianopalette.cpp" line="368"/>
        <source>#*</source>
        <translation>#*</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="241"/>
        <source>Single color highlight</source>
        <translation>Color único de resaltado</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="242"/>
        <source>A single color to highlight all note events</source>
        <translation>Un único color para resaltar todos los eventos de notas</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="246"/>
        <source>Two colors highlight</source>
        <translation>Dos colores de resaltado</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="247"/>
        <source>One color to highlight natural notes and a different one for accidentals</source>
        <translation>Un color para resaltar las notas naturales y otro diferente para las alteraciones</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="251"/>
        <source>MIDI Channels highlight</source>
        <translation>Resaltado por Canales MIDI</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="252"/>
        <source>A different color to highlight each MIDI channel. Enable Omni mode in the MIDI IN connection</source>
        <translation>Un color diferente para resaltar cada canal MIDI. Habilitar modo Omni en la conexión MIDI IN</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="256"/>
        <source>Chromatic scale background</source>
        <translation>Escala cromática (fondode teclas)</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="257"/>
        <location filename="../pianopalette.cpp" line="272"/>
        <source>One color for each note in the chromatic scale</source>
        <translation>Un color para cada nota de la escala cromática</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="261"/>
        <source>Keys background</source>
        <translation>Fondo de teclas</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="262"/>
        <source>One color for natural notes and another for accidentals</source>
        <translation>Un color para las notas naturales y otro para las accidentales</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="266"/>
        <source>Font foreground</source>
        <translation>Primer plano de fuente</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="267"/>
        <source>Colors for note names</source>
        <translation>Colores para los nombres de notas</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="271"/>
        <source>Chromatic scale highlight</source>
        <translation>Escala cromática (resaltado)</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::FluidSettingsDialog</name>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="14"/>
        <source>FluidSynth Driver Settings</source>
        <translation>Opciones del controlador de FluidSynth</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="123"/>
        <source>Sample Rate:</source>
        <translation>Frecuencia de muestreo:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="106"/>
        <source>Period Size:</source>
        <translation>Tamaño del periodo:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="159"/>
        <source># of Periods:</source>
        <translation>Número de periodos:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="39"/>
        <source>Audio Driver:</source>
        <translation>Controlador de audio:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="169"/>
        <source>Polyphony:</source>
        <translation>Polifonía:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="89"/>
        <source>FluidSynth Version:</source>
        <translation>Versión de Fluidsynth:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="69"/>
        <source>Sound Font:</source>
        <translation>SoundFont:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="116"/>
        <source>Initialization Status:</source>
        <translation>Estado de inicialización:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="185"/>
        <source>Buffer Time:</source>
        <translation>Tiempo de buffer:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="192"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="49"/>
        <source>Gain:</source>
        <translation>Ganancia:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="152"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="139"/>
        <source>Chorus</source>
        <translation>Coral</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="62"/>
        <source>Reverb</source>
        <translation>Reverberación</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="140"/>
        <source>FluidSynth Initialized</source>
        <translation>FluidSynth inicializado</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="140"/>
        <source>FluidSynth Initialization Failed</source>
        <translation>Inicialización fallida de FluidSynth</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="206"/>
        <source>Ready</source>
        <translation>Listo</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="206"/>
        <source>Failed</source>
        <translation>Fallido</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="334"/>
        <source>Select SoundFont</source>
        <translation>Seleccionar SoundFont</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="334"/>
        <source>SoundFont Files (*.sf2 *.sf3 *.dls)</source>
        <translation>Archivos SoundFont (*.sf2 *.sf3 *.dls)</translation>
    </message>
    <message>
        <source>SoundFont Files (*.sf2)</source>
        <translation type="vanished">Archivos SoundFont (*.sf2)</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::MacSynthSettingsDialog</name>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="14"/>
        <source>macOS Synth Driver Settings</source>
        <translation>Opciones del controlador del sintetizador de macOS</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="56"/>
        <source>SoundFont:</source>
        <translation>SoundFont:</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="76"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="83"/>
        <source>Use Internal Reverb</source>
        <translation>Utilizar reverberación interna</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="90"/>
        <source>Init. Status:</source>
        <translation>Estado de inicialización:</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="69"/>
        <source>Default Apple DLS Sound Set</source>
        <translation>Conjunto de sonidos DLS de Apple por omisión</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="72"/>
        <source>DLS Synth Initialized</source>
        <translation>Sintetizador DLS inicializado</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="72"/>
        <source>DLS Synth Initialization Failed</source>
        <translation>Inicialización fallida del sintetizador DLS</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="122"/>
        <source>Ready</source>
        <translation>Listo</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="122"/>
        <source>Failed</source>
        <translation>Fallido</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="163"/>
        <source>Select SoundFont</source>
        <translation>Seleccionar SoundFont</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="163"/>
        <source>SoundFont Files (*.sf2 *.dls)</source>
        <translation>Archivos SoundFont (*.sf2 *.dls)</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::NetworkSettingsDialog</name>
    <message>
        <location filename="../networksettingsdialog.ui" line="14"/>
        <source>Network Driver Settings</source>
        <translation>Opciones del controlador de red</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="33"/>
        <source>Init. Status:</source>
        <translation>Estado de inicialización:</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="50"/>
        <source>Use IPv6</source>
        <translation>Usar IPv6</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="57"/>
        <source>Network Interface:</source>
        <translation>Interfaz de red:</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="70"/>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="76"/>
        <source>Network Initialized</source>
        <translation>Red inicializada</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="76"/>
        <source>Network Initialization Failed</source>
        <translation>Inicialización fallida de la red</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="111"/>
        <location filename="../networksettingsdialog.cpp" line="174"/>
        <source>Any</source>
        <translation>Cualquiera</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="164"/>
        <source>Ready</source>
        <translation>Listo</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="164"/>
        <source>Failed</source>
        <translation>Fallido</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::PianoScene</name>
    <message>
        <location filename="../pianoscene.cpp" line="1301"/>
        <location filename="../pianoscene.cpp" line="1314"/>
        <source>C</source>
        <translation>do</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1302"/>
        <source>C♯</source>
        <translation>do♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1303"/>
        <location filename="../pianoscene.cpp" line="1316"/>
        <source>D</source>
        <translation>re</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1304"/>
        <source>D♯</source>
        <translation>re♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1305"/>
        <location filename="../pianoscene.cpp" line="1318"/>
        <source>E</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1306"/>
        <location filename="../pianoscene.cpp" line="1319"/>
        <source>F</source>
        <translation>fa</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1307"/>
        <source>F♯</source>
        <translation>fa♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1308"/>
        <location filename="../pianoscene.cpp" line="1321"/>
        <source>G</source>
        <translation>sol</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1309"/>
        <source>G♯</source>
        <translation>sol♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1310"/>
        <location filename="../pianoscene.cpp" line="1323"/>
        <source>A</source>
        <translation>la</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1311"/>
        <source>A♯</source>
        <translation>la♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1312"/>
        <location filename="../pianoscene.cpp" line="1325"/>
        <source>B</source>
        <translation>si</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1315"/>
        <source>D♭</source>
        <translation>re♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1317"/>
        <source>E♭</source>
        <translation>mi♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1320"/>
        <source>G♭</source>
        <translation>sol♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1322"/>
        <source>A♭</source>
        <translation>la♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1324"/>
        <source>B♭</source>
        <translation>si♭</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::SonivoxSettingsDialog</name>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="14"/>
        <source>Sonivox EAS Synth</source>
        <translation>Sintetizador Sonivox EAS</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="26"/>
        <source>Chorus</source>
        <translation>Coral</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="43"/>
        <source>Reverb</source>
        <translation>Reverberación</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="71"/>
        <source>Buffer Time:</source>
        <translation>Tiempo de buffer:</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="81"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="110"/>
        <source>Init. Status:</source>
        <translation>Estado de inicialización:</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="85"/>
        <source>Sonivox Initialized</source>
        <translation>Sonivox inicializado</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="85"/>
        <source>Sonivox Initialization Failed</source>
        <translation>Inicialización fallida de Sonivox</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="165"/>
        <source>Ready</source>
        <translation>Listo</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="165"/>
        <source>Failed</source>
        <translation>Fallido</translation>
    </message>
</context>
</TS>
